@@ -1,8 +1,6 @@
 #-*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from django.core import validators
-#from django.core.exceptions import ValidationError
 from django.forms import fields
 from django.utils.translation import ugettext_lazy as _
 
@@ -14,8 +12,11 @@ class LikertField(fields.IntegerField):
     default_error_messages = {
         'invalid': _('Please rate how strongly you agree or disagree with '
                      'the statement.'),
-        'min_value': _('Ensure your response is greater than or equal to %(limit_value)s.'),
-        'max_value': _('Ensure your response is less than or equal to %(limit_value)s.'),
+        'min_value': _(
+            'Ensure your response is greater than or equal to '
+            '%(limit_value)s.'),
+        'max_value': _(
+            'Ensure your response is less than or equal to %(limit_value)s.'),
     }
 
     def __init__(self, min_value=0, *args, **kwargs):
